summaryrefslogtreecommitdiffstats
path: root/Core/Exception
diff options
context:
space:
mode:
Diffstat (limited to 'Core/Exception')
-rw-r--r--Core/Exception/AuthenticationException.php2
-rw-r--r--Core/Exception/UnsupportedUserException.php (renamed from Core/Exception/UnsupportedAccountException.php)4
2 files changed, 3 insertions, 3 deletions
diff --git a/Core/Exception/AuthenticationException.php b/Core/Exception/AuthenticationException.php
index a01d6b8..074dad0 100644
--- a/Core/Exception/AuthenticationException.php
+++ b/Core/Exception/AuthenticationException.php
@@ -18,7 +18,7 @@ namespace Symfony\Component\Security\Core\Exception;
*/
class AuthenticationException extends \RuntimeException implements \Serializable
{
- protected $extraInformation;
+ private $extraInformation;
public function __construct($message, $extraInformation = null, $code = 0, \Exception $previous = null)
{
diff --git a/Core/Exception/UnsupportedAccountException.php b/Core/Exception/UnsupportedUserException.php
index 9859c1d..5be9bc4 100644
--- a/Core/Exception/UnsupportedAccountException.php
+++ b/Core/Exception/UnsupportedUserException.php
@@ -13,10 +13,10 @@ namespace Symfony\Component\Security\Core\Exception;
/**
* This exception is thrown when an account is reloaded from a provider which
* doesn't support the passed implementation of AccountInterface.
*
* @author Johannes M. Schmitt <schmittjoh@gmail.com>
*/
-class UnsupportedAccountException extends AuthenticationServiceException
+class UnsupportedUserException extends AuthenticationServiceException
{
} \ No newline at end of file
@@ -13,10 +13,10 @@ namespace Symfony\Component\Security\Core\Exception;
/**
* This exception is thrown when an account is reloaded from a provider which
- * doesn't support the passed implementation of AccountInterface.
+ * doesn't support the passed implementation of UserInterface.
*
* @author Johannes M. Schmitt <schmittjoh@gmail.com>